@@ -15,9 +15,9 @@ use Config::IniFiles;
 use Carp;
 use English qw(-no_match_vars);
 
-our $VERSION = q[0.08];
+our $VERSION = q[0.09];
 our $CONFIGS = {
-		default => map { m{([a-z\d_\./]+)}mix } ($ENV{MODULE_PORTABLEPATH_CONF} || q[/etc/perlconfig.ini]),
+		default => map { m{([[:lower:][:digit:]_./]+)}smix } ($ENV{MODULE_PORTABLEPATH_CONF} || q[/etc/perlconfig.ini]),
 	       };
 
 sub config {
@@ -25,7 +25,7 @@ sub config {
   my $hostname = hostname() || q[];
 
   for my $k (sort { length $a <=> length $b } keys %{$CONFIGS}) {
-    if($hostname =~ /$k/mx) {
+    if($hostname =~ /$k/smx) {
       $cfgfile = $CONFIGS->{$k};
       last;
     }
@@ -62,7 +62,7 @@ sub _import_libs {
   my $reverse      = {};
 
   for my $param ($config->Parameters('libs')) {
-    for my $v (split /[,\s;:]+/mx, $config->val('libs', $param)||q[]) {
+    for my $v (split /[,\s;:]+/smx, $config->val('libs', $param)||q[]) {
       $reverse->{$v} = $param;
       unshift @{$forward->{$param}}, $v;
     }
@@ -74,18 +74,18 @@ sub _import_libs {
       next;
     }
 
-    my ($tag) = $reverse->{$i} =~ /([a-z]+)/mx;
+    my ($tag) = $reverse->{$i} =~ /([[:lower:]]+)/smx;
     $seentags->{$tag} = $reverse->{$i};
   }
 
   for my $a (@args) {
     if(!$forward->{$a}) {
-      carp qq(Use of unknown tag "$a");
+      carp qq[Use of unknown tag "$a"];
     }
     for my $i (@{$forward->{$a}}) {
-      my ($tag) = $reverse->{$i} =~ /([a-z]+)/mx;
+      my ($tag) = $reverse->{$i} =~ /([[:lower:]]+)/smx;
       if($seentags->{$tag} && ($seentags->{$tag} ne $reverse->{$i})) {
-	carp qq(Import of tag "$a" may clash with tag "$seentags->{$tag}");
+	carp qq[Import of tag "$a" may clash with tag "$seentags->{$tag}"];
       }
       unshift @INC, $i;
     }
@@ -97,10 +97,10 @@ sub _import_ldlibs {
   my ($pkg, $config, @args) = @_;
   my $forward      = {};
   my $reverse      = {};
-  my @LDLIBS       = split /:/mx, $ENV{LD_LIBRARY_PATH}||q[];
+  my @LDLIBS       = split /:/smx, $ENV{LD_LIBRARY_PATH}||q[];
 
   for my $param ($config->Parameters('ldlibs')) {
-    for my $v (split /[,\s;:]+/mx, $config->val('ldlibs', $param) || q[]) {
+    for my $v (split /[,\s;:]+/smx, $config->val('ldlibs', $param) || q[]) {
       $reverse->{$v} = $param;
       unshift @{$forward->{$param}}, $v;
     }
@@ -111,7 +111,7 @@ sub _import_ldlibs {
     if(!$reverse->{$i}) {
       next;
     }
-    my ($tag) = $reverse->{$i} =~ /([a-z]+)/mx;
+    my ($tag) = $reverse->{$i} =~ /([[:lower:]]+)/smx;
     $seentags->{$tag} = $reverse->{$i};
   }
 
@@ -121,24 +121,24 @@ sub _import_ldlibs {
     }
 
     for my $i (@{$forward->{$a}}) {
-      my ($tag) = $reverse->{$i} =~ /([a-z]+)/mx;
+      my ($tag) = $reverse->{$i} =~ /([[:lower:]]+)/smx;
       if($seentags->{$tag} && ($seentags->{$tag} ne $reverse->{$i})) {
-	carp qq(Import of tag "$a" may clash with tag "$seentags->{$tag}");
+	carp qq[Import of tag "$a" may clash with tag "$seentags->{$tag}"];
       }
       unshift @LDLIBS, $i;
     }
   }
 
-  $ENV{'LD_LIBRARY_PATH'} = join q(:), @LDLIBS;
+  $ENV{'LD_LIBRARY_PATH'} = join q[:], @LDLIBS; ## no critic (RequireLocalizedPunctuationVars)
   return;
 }
 
-sub dump { ## no critic
+sub dump { ## no critic (Homonyms)
   my $config = config();
   for my $l (qw(Libs LDlibs)) {
     print $l, "\n" or croak $ERRNO;
     for my $s (sort $config->Parameters(lc $l)) {
-      printf qq(%-12s %s\n), $s, $config->val(lc $l, $s);
+      printf qq[%-12s %s\n], $s, $config->val(lc $l, $s);
     }
     print "\n\n" or croak $ERRNO;
   }
